@@ -9,33 +9,40 @@
 #' the latter a stochastic search does that job. This function has the option
 #' to do all the mentioned tasks in a parallel fashion, exploiting hundreds of
 #' CPUs. It is highly recommended to use a cluster for this purpose. This
-#' function also supports having fixed columns in the design matrix which are
-#' always in the final model and do not enter the selection procedure. Clinical
-#' variables such as age, gender or stage of cancer are some examples. For the
-#' output, it reports necessary measurements that is common in Bayesian
-#' variable selection algorithms. They include Highest Posterior Probability
-#' model, median probability model and posterior inclusion probability for each
-#' of the covariates in the design matrix.
+#' function also supports fixing covariates in variable selection process,
+#' thus making them included in the final selected model with probability 1.
+#' Categorical variable are also supported by this function as input covariates
+#' to the selection process. They need to be well defined factor variables as
+#' part of the input data frame. For the output, this function reports
+#' necessary measurements that is common in Bayesian variable selection
+#' algorithms. They include Highest Posterior Probability model, median
+#' probability model and posterior inclusion probability for each of the
+#' covariates in the design matrix.
 #'
-#' @param X The \code{n} times \code{p} design matrix. The columns should
-#' represent genes and rows represent the observations. The column names are
-#' used as gene names so they should not be left as \code{NULL}. Moreover,
-#' the minimum number of columns allowed is 3. For logistic regression, 
-#' \code{X} should NOT contain vector of \code{1}'s representing the intercept
-#' as it will be added automatically.
+#' @param X The \code{n} times \code{p} input data frame containing the
+#' covariates in the design matrix. The columns should represent genes and rows
+#' represent the observed samples. The column names are used as gene names so
+#' they should not be left as \code{NULL}. Moreover, the minimum number of
+#' columns allowed is 3. The input data frame can also contain categorical
+#' covariates that are appropriately defined as factor variables in R.
 #' @param resp For logistic regression models it is the binary response
 #' vector. For Cox proportional hazard models this is a two column matrix
 #' where the first column contains survival time vector and the second column
 #' is the censoring status for each observation.
-#' @param prep A logical value determining if the preprocessing step should
+#' @param prep A boolean variable determining if the preprocessing step should
 #' be performed on the design matrix or not. That step contains removing
 #' columns that have \code{NA}'s or all their elements are equal to 0, along
 #' with standardizing non-binary columns. This step is recommended and thus the
 #' default value is \code{TRUE}.
-#' @param fixed_cols A vector of indices showing those columns of the design
-#' matrix that are not supposed to enter the selection procedure. These
+#' @param logT A boolean variable determining if log transform should be done
+#' on continuous columns before scaling them in the preprocessing step.
+#' Note that those columns should not contain any zeros or negative values.
+#' @param fixed_cols A vector of indices showing the columns in the input
+#' data frame that are not subject to the the selection procedure. These
 #' columns are always in the final selected model. Note that if any of these
-#' columns contain \code{NA}, they will be removed.
+#' columns contain \code{NA}, they will be removed. Moreover, if a categorical
+#' variable with \code{k} levels is chosen to be fixed, all \code{k-1} dummy
+#' variables associated with it will be selected in the final model. 
 #' @param eff_size This is the expected effect size in the model for a
 #' standardized design matrix, which is basically the coefficient value that is
 #' expected to occur the most based on some prior knowledge.
@@ -234,6 +241,7 @@
 #' probs <- as.vector(exp(XB)/(1+exp(XB)))
 #' y <- rbinom(n,1,probs)
 #' colnames(X) <- paste("gene_",c(1:p),sep="")
+#' X <- as.data.frame(X)
 #'
 #' ### Running 'bvs' function without coupling and with hyperparamter selection
 #' ### procedure
@@ -248,31 +256,19 @@
 #' 
 #' ### Number of Visited Models:
 #' bout$num_vis_models
-bvs <- function(X, resp, prep = TRUE, fixed_cols = NULL, eff_size = 0.5,
-                family = c("logistic", "survival"), hselect = TRUE,
-                nlptype = "piMOM", r = 1, tau = 0.25, niter = 30,
-                mod_prior = c("unif", "beta"), inseed = NULL, cplng = FALSE,
-                ncpu = 4, parallel.MPI=FALSE){
+bvs <- function(X, resp, prep = TRUE, logT = FALSE, fixed_cols = NULL,
+                eff_size = 0.5, family = c("logistic", "survival"),
+                hselect = TRUE, nlptype = "piMOM", r = 1, tau = 0.25,
+                niter = 30, mod_prior = c("unif", "beta"), inseed = NULL,
+                cplng = FALSE, ncpu = 4, parallel.MPI=FALSE){
+  
+  if(!class(X)=="data.frame") stop("input X should be a data frame!") 
+  ol <- matprep(X, fixed_cols, prep, logT)
+  X <- ol$fulmat
+  gnames <- ol$gnames
+  nf <- ol$nf
   
   if(family=="logistic"){
-    # ==================== Data pre-processing =======================
-    
-    nf <- length(fixed_cols)
-    if (nf){
-      X1 <- X[,fixed_cols]; g1 <- colnames(X[,fixed_cols])
-      X2 <- X[,-fixed_cols]; g2 <- colnames(X[,-fixed_cols])
-      X <- cbind(X1,X2); colnames(X) <- c(g1,g2)
-      if(length(which(is.na(X1)))) warning("At least one of fixed columns contain NA and will be removed if preprocessing is activated!")
-    }
-    
-    if (prep){
-      Xin <- PreProcess(X)
-      X <- Xin$X
-      gnames <- Xin$gnames
-    } else{
-      gnames <- colnames(X)
-    }
-    
     y <- as.numeric(resp)
     dx <- dim(X)
     n <- dx[1]
@@ -468,27 +464,13 @@ bvs <- function(X, resp, prep = TRUE, fixed_cols = NULL, eff_size = 0.5,
   
   ### ================================================================= 
   if(family=="survival"){
+    
     TS <- resp
     time <- TS[, 1]
     status <- TS[, 2]
     
-    nf <- length(fixed_cols)
-    if (nf){
-      X1 <- X[,fixed_cols]; g1 <- colnames(X[,fixed_cols])
-      X2 <- X[,-fixed_cols]; g2 <- colnames(X[,-fixed_cols])
-      X <- cbind(X1,X2); colnames(X) <- c(g1,g2)
-      if(length(which(is.na(X1)))) warning("At least one of fixed columns contain NA and will be removed if preprocessing is activated!")
-    }
     sfidx <- nf+1
     
-    if (prep){
-      Xin <- PreProcess(X)
-      X <- Xin$X
-      gnames <- Xin$gnames
-    } else{
-      gnames <- colnames(X)
-    }
-    
     dx <- dim(X)
     n <- dx[1]
     p <- dx[2]
